==> voreen-src-4.4-win.zip: voreen-src-4.4-win/include/voreen/core/properties/progressproperty.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2013 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_PROGRESSPROPERTY_H
#define VRN_PROGRESSPROPERTY_H

#include "voreen/core/properties/property.h"
#include "voreen/core/io/progressreporter.h"

namespace voreen {

class VRN_CORE_API ProgressProperty : public Property, public ProgressReporter {
public:
    ProgressProperty(const std::string& id, const std::string& guiText);
    ProgressProperty();
    virtual ~ProgressProperty();

    virtual Property* create() const;

    virtual std::string getClassName() const       { return "ProgressProperty"; }
    virtual std::string getTypeDescription() const { return "Progress Bar"; }

    virtual void reset();

    virtual void setProgress(float progress);
    virtual float getProgress() const;

    virtual void setProgressRange(const tgt::vec2& progressRange);
    virtual tgt::vec2 getProgressRange() const;

    virtual void setProgressMessage(const std::string& message);
    std::string getProgressMessage() const;

private:
    float progress_;
    tgt::vec2 progressRange_;
    std::string message_;
};

}   // namespace

#endif

==> voreen-src-5.0.1-win.zip: voreen-src-5.0.1-win/include/voreen/core/properties/progressproperty.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2018 University of Muenster, Germany,                        *
 * Department of Computer Science.                                                 *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_PROGRESSPROPERTY_H
#define VRN_PROGRESSPROPERTY_H

#include "voreen/core/properties/property.h"
#include "voreen/core/io/progressreporter.h"

namespace voreen {

/**
 * This Property can be used to get a visual feedback of the progress during application mode.
 * If a Processor usesExpensiveCompuation, it will automatically get a progress bar during the
 * network mode. To get a feedback in application mode, add this Property to the Processor and
 * call Processor::addProgressBar(...) with this as parameter.
 * The progress can be set via setProgress() in the Processor.
 */
class VRN_CORE_API ProgressProperty : public Property, public ProgressReporter {
public:
    ProgressProperty(const std::string& id, const std::string& guiText);
    ProgressProperty();
    virtual ~ProgressProperty();

    virtual Property* create() const;

    virtual std::string getClassName() const       { return "ProgressProperty"; }
    virtual std::string getTypeDescription() const { return "Progress Bar"; }

    virtual void reset();

    virtual void setProgressMessage(const std::string& message);
    std::string getProgressMessage() const;

    virtual void update();

private:

    std::string message_;
};

}   // namespace

#endif
